Defines the AcousticPSU process data, linking strata, acoustic PSUs and EDSUs.
The current data produced by a previous instance of the function.
Logical: If TRUE use the existing function output in the process.
The StratumPolygon process data.
StoxAcousticData (defined in RstoxData).
Character: A string naming the method to use, one of "Manual" for manual tagging of EDUSs to PSUs (passes the process data through the function unchanged); "EDSUToPSU", which sets each EDSU as a PSU; "DeleteAllPSUs" to delete all PSUs; "PreDefined" to read from a previous process; and "ResourceFile" to read from either a project.xml file from StoX <= 2.7, a project.json file from StoX >=3.0.0, or a file containing a PSUByTime table.
The path to a resource file from which to read PSUs, in the case that DefinitionMethod is "ResourceFile". Accepts both project.xml from the old StoX 2.7, project.json from the new StoX >= 3.0.0, or a table that could be read by fread containing the columns "Stratum", "PSU", "Cruise", "StartDateTime" and "StopDateTime". Must include file extension.
The AcousticPSU process data.
An object of StoX data type AcousticPSU.
Note that if the FileName is a project.xml file, it is assumed that the contents of the file is actually used in the StoX <= 2.7 project, i.e. that UseProcessData = TRUE in DefineAcousticPSU().
If the the FileName comtains a table with PSUByTime info, the following columns are required: "Stratum", "PSU", "Cruise", "StartDateTime", "StopDateTime".
Biotic PSUs are generated using DefineBioticPSU. For the vertical resolution (Layer) see DefineBioticLayer and DefineAcousticLayer.