The ReportTransectDesignData model data is a list of three tables Segment, SegmentWithTransit and Stratum.
The table Transect stores the transect segments from the input TransectDesignData and contains the columns Stratum (character), Transect(character), Segment (character), LongitudeStart (decimal degrees), LatitudeStart (decimal degrees), LongitudeEnd (decimal degrees), LatitudeEnd (decimal degrees), Speed (knots), Direction (character: "Tour"/"Retour"), SegmentType (character: "Transect"/"Transit"), Distance (nautical mile), and Duration (hours).
The table Stratum stores one row per stratum and direction with the columns Stratum (character), Direction (character: "Tour"/"Retour"), DistanceSegment (nautical mile), DistanceTransit (nautical mile), Distance (nautical mile), Speed (knots), Area (square nautical mile), Coverage (DistanceSegment / square root of Area) and Duration (hours).
This data type is produced by ReportTransectDesign. See DataTypes for a list of all StoX data types produced by RstoxBase.