Get base unit of a variable of a StoX dataType

getBaseUnit(
  dataType,
  variableName,
  variableType = NULL,
  element = c("unit", "quantity"),
  list.out = FALSE
)

Arguments

dataType

The name of a StoX DataTypes.

variableName

The variable name to get base units from.

variableType

For variables with more than one interpretation, such as Density, which is dependent on the DensityType. The type is given in the getRstoxBaseDefinitions("dataTypeUnits").

element

The element to get, one of "unit" and "quantity".

list.out

Logical: If TRUE return both elements in a list.