Set units to a variable of the StoX dataType

setUnitRstoxBase(x, dataType, variableName, variableType = NULL, unit = NULL)

Arguments

x

A StoX data

dataType

The name of a StoX DataTypes.

variableName

The variable name to get base units from.

variableType

For variables with more than one interpretation, such as Density, which is dependent on the DensityType. The type is given in the getRstoxBaseDefinitions("dataTypeUnits").

unit

The unit to set to the variable of the StoX Data