Get base unit of a variable of a StoX dataType
getBaseUnit(
dataType,
variableName,
variableType = NULL,
element = c("unit", "quantity"),
list.out = FALSE
)The name of a StoX DataTypes.
The variable name to get base units from.
For variables with more than one interpretation, such as Density, which is dependent on the DensityType. The type is given in the getRstoxBaseDefinitions("dataTypeUnits").
The element to get, one of "unit" and "quantity".
Logical: If TRUE return both elements in a list.