Set base unit to a variable of the StoX dataType
setBaseUnit(x, dataType, variableName, variableType = NULL)The object to set base units to.
The name of a StoX DataTypes.
The variable name to get base units from.
For variables with more than one interpretation, such as Density, which is dependent on the DensityType. The type is given in the getRstoxBaseDefinitions("dataTypeUnits").