Set units to a variable of the StoX dataType
setUnitRstoxBase(x, dataType, variableName, variableType = NULL, unit = NULL)A StoX data
The name of a StoX DataTypes.
The variable name to get base units from.
For variables with more than one interpretation, such as Density, which is dependent on the DensityType. The type is given in the getRstoxBaseDefinitions("dataTypeUnits").
The unit to set to the variable of the StoX Data